@@ -68,6 +68,9 @@ class FileCache():
                     self.getEngine(using_area=area).set_namespace(namespace=self.namespace).set(key=key,
                                                                                                 file_path=file_path,
                                                                                                 del_local=False)
+            if del_local:
+                if os.path.exists(file_path):
+                    os.remove(file_path)
         else:
             return self.default_engine.set_namespace(namespace=self.namespace).set(key=key, file_path=file_path,
                                                                                    del_local=del_local)
@@ -118,7 +121,7 @@ class FileCache():
 
     @runtime_logging
     def exist(self, key):
-            return self.default_engine.set_namespace(namespace=self.namespace).exist(key=key)
+        return self.default_engine.set_namespace(namespace=self.namespace).exist(key=key)
 
     @runtime_logging
     def list_cache_objects(self):
